@@ -746,6 +746,11 @@ brasero_file_node_set_from_info (BraseroFileNode *node,
 		stats->children ++;
 	}
 
+	if (!node->is_symlink && (g_file_info_get_file_type (info) != G_FILE_TYPE_SYMBOLIC_LINK)) {
+		/* only count files */
+		stats->num_sym ++;
+	}
+
 	/* update :
 	 * - the mime type
 	 * - the size (and possibly the one of his parent)
@@ -755,7 +760,7 @@ brasero_file_node_set_from_info (BraseroFileNode *node,
 	node->is_loading = FALSE;
 	node->is_imported = FALSE;
 	node->is_reloading = FALSE;
-	node->is_symlink = (g_file_info_get_is_symlink (info));
+	node->is_symlink = (g_file_info_get_file_type (info) == G_FILE_TYPE_SYMBOLIC_LINK);
 
 	if (node->is_file) {
 		guint sectors;
@@ -1050,6 +1055,10 @@ brasero_file_node_destroy_with_children (BraseroFileNode *node,
 		if (node->is_deep)
 			stats->num_deep --;
 
+		/* check if that's a symlink */
+		if (node->is_symlink)
+			stats->num_sym --;
+
 		/* update file number statistics */
 		if (!node->is_imported && node->is_file)
 			stats->children --;
