@@ -33,7 +33,7 @@
 
 #include "burn-basics.h"
 #include "burn-caps.h"
-#include "burn-drive.h"
+#include "brasero-drive.h"
 
 #include "brasero-utils.h"
 #include "brasero-image-type-chooser.h"
@@ -141,11 +141,11 @@ static void
 brasero_src_image_set_track (BraseroSrcImage *dialog,
 			     BraseroImageFormat format,
 			     const gchar *image,
-			     const gchar *toc,
-			     guint64 size)
+			     const gchar *toc)
 {
 	gchar *path;
 	gchar *string;
+	gint64 size = 0;
 	gchar *size_string;
 	BraseroSrcImagePrivate *priv;
 
@@ -191,6 +191,7 @@ brasero_src_image_set_track (BraseroSrcImage *dialog,
 	if (!toc && !image && format == BRASERO_IMAGE_FORMAT_NONE)
 		return;
 
+	brasero_track_get_image_size (priv->track, NULL, NULL, &size, NULL);
 	size_string = g_format_size_for_display (size);
 	path = NULL;
 	switch (format) {
@@ -240,7 +241,7 @@ brasero_src_image_error (BraseroSrcImage *self,
 			 GError *error)
 {
 	brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (self)),
-				      _("Please, select another image."),
+				      _("Please select another image."),
 				      error->message,
 				      GTK_MESSAGE_ERROR);
 }
@@ -258,13 +259,11 @@ brasero_src_image_image_info_cb (GObject *object,
 	const gchar *mime;
 
 	priv = BRASERO_SRC_IMAGE_PRIVATE (dialog);
-
 	if (error) {
 		brasero_src_image_set_track (dialog,
 					     BRASERO_IMAGE_FORMAT_NONE,
 					     NULL,
-					     NULL,
-					     0);
+					     NULL);
 
 		/* we need to say that image can't be loaded */
 		brasero_src_image_error (dialog, error);
@@ -279,29 +278,25 @@ brasero_src_image_image_info_cb (GObject *object,
 			brasero_src_image_set_track (dialog,
 						     format,
 						     uri,
-						     NULL,
-						     g_file_info_get_size (info));
+						     NULL);
 			return;
 		case BRASERO_IMAGE_FORMAT_CUE:
 			brasero_src_image_set_track (dialog,
 						     format,
 						     NULL,
-						     uri,
-						     g_file_info_get_size (info));
+						     uri);
 			return;
 		case BRASERO_IMAGE_FORMAT_CDRDAO:
 			brasero_src_image_set_track (dialog,
 						     format,
 						     NULL,
-						     uri,
-						     g_file_info_get_size (info));
+						     uri);
 			return;
 		case BRASERO_IMAGE_FORMAT_CLONE:
 			brasero_src_image_set_track (dialog,
 						     format,
 						     NULL,
-						     uri,
-						     g_file_info_get_size (info));
+						     uri);
 			return;
 
 		/* handle those cases afterwards */
@@ -326,20 +321,17 @@ brasero_src_image_image_info_cb (GObject *object,
 			brasero_src_image_set_track (dialog,
 						     format,
 						     NULL,
-						     uri,
-						     g_file_info_get_size (info));
+						     uri);
 		else if (g_str_has_suffix (path, ".toc"))
 			brasero_src_image_set_track (dialog,
 						     BRASERO_IMAGE_FORMAT_CLONE,
 						     NULL,
-						     uri,
-						     g_file_info_get_size (info));
+						     uri);
 		else
 			brasero_src_image_set_track (dialog,
 						     BRASERO_IMAGE_FORMAT_NONE,
 						     NULL,
-						     uri,
-						     g_file_info_get_size (info));
+						     uri);
 	}
 	else if (mime && !strcmp (mime, "application/octet-stream")) {
 		/* that could be an image, so here is the deal:
@@ -349,33 +341,28 @@ brasero_src_image_image_info_cb (GObject *object,
 			brasero_src_image_set_track (dialog,
 						     BRASERO_IMAGE_FORMAT_CDRDAO,
 						     uri,
-						     NULL,
-						     g_file_info_get_size (info));
+						     NULL);
 		else if (g_str_has_suffix (uri, ".raw"))
 			brasero_src_image_set_track (dialog,
 						     BRASERO_IMAGE_FORMAT_CLONE,
 						     uri,
-						     NULL,
-						     g_file_info_get_size (info));
+						     NULL);
 		else
 			brasero_src_image_set_track (dialog,
 						     BRASERO_IMAGE_FORMAT_BIN,
 						     uri,
-						     NULL,
-						     g_file_info_get_size (info));
+						     NULL);
 	}
 	else if (mime && !strcmp (mime, "application/x-cd-image"))
 		brasero_src_image_set_track (dialog,
 					     BRASERO_IMAGE_FORMAT_BIN,
 					     uri,
-					     NULL,
-					     g_file_info_get_size (info));
+					     NULL);
 	else
 		brasero_src_image_set_track (dialog,
 					     BRASERO_IMAGE_FORMAT_NONE,
 					     uri,
-					     NULL,
-					     g_file_info_get_size (info));
+					     NULL);
 }
 
 static void
@@ -438,8 +425,7 @@ brasero_src_image_get_format (BraseroSrcImage *dialog,
 		brasero_src_image_set_track (dialog,
 					     BRASERO_IMAGE_FORMAT_NONE,
 					     NULL,
-					     NULL,
-					     0);
+					     NULL);
 		return;
 	}
 
@@ -645,8 +631,7 @@ brasero_src_image_set_uri (BraseroSrcImage *self,
 		brasero_src_image_set_track (self,
 					     BRASERO_IMAGE_FORMAT_NONE,
 					     NULL,
-					     NULL,
-					     0);
+					     NULL);
 }
 
 static void
